==> pegasus-merchandise-api-1.3.1-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsSkuCategoryCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**  
 * @Author: LK【kai.li@thebeastshop.com】
 * @Date: 2017/5/10 16:23
 */
public class PcsSkuCategoryCond extends BaseQueryCond implements Serializable {

    public PcsSkuCategoryCond() {
        super();
    }

    private List<Long> LabelIds; //标签

    private List<Long> categoryIds; //类目Ids

    private List<Long> brandIds; //品牌

    private String channelCode; //渠道

    private List<Long> productIds; //产品Ids

    private List<Long> ids; //前台类目Ids

    private List<String> codes; //前台类目Codes

    public List<Long> getLabelIds() {
        return LabelIds;
    }

    public void setLabelIds(List<Long> labelIds) {
        LabelIds = labelIds;
    }

    public List<Long> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Long> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public List<Long> getBrandIds() {
        return brandIds;
    }

    public void setBrandIds(List<Long> brandIds) {
        this.brandIds = brandIds;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public List<Long> getProductIds() {
        return productIds;
    }

    public void setProductIds(List<Long> productIds) {
        this.productIds = productIds;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public List<String> getCodes() {
        return codes;
    }

    public void setCodes(List<String> codes) {
        this.codes = codes;
    }
}

==> pegasus-merchandise-api-1.4.27-sources.jar: com/thebeastshop/pegasus/merchandise/cond/PcsSkuCategoryCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.io.Serializable;
import java.util.List;

/**  
 * @Author: LK【kai.li@thebeastshop.com】
 * @Date: 2017/5/10 16:23
 */
public class PcsSkuCategoryCond extends BaseQueryCond implements Serializable {

    public PcsSkuCategoryCond() {
        super();
    }

    private List<Long> LabelIds; //标签

    private List<Long> categoryIds; //类目Ids

    private List<Long> brandIds; //品牌

    private String channelCode; //渠道

    private List<Long> productIds; //产品Ids

    private List<Long> ids; //前台类目Ids

    private List<String> codes; //前台类目Codes

    private String splice;

    public List<Long> getLabelIds() {
        return LabelIds;
    }

    public void setLabelIds(List<Long> labelIds) {
        LabelIds = labelIds;
    }

    public List<Long> getCategoryIds() {
        return categoryIds;
    }

    public void setCategoryIds(List<Long> categoryIds) {
        this.categoryIds = categoryIds;
    }

    public List<Long> getBrandIds() {
        return brandIds;
    }

    public void setBrandIds(List<Long> brandIds) {
        this.brandIds = brandIds;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public List<Long> getProductIds() {
        return productIds;
    }

    public void setProductIds(List<Long> productIds) {
        this.productIds = productIds;
    }

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public List<String> getCodes() {
        return codes;
    }

    public void setCodes(List<String> codes) {
        this.codes = codes;
    }

    public String getSplice() {
        return splice;
    }

    public void setSplice(String splice) {
        this.splice = splice;
    }
}
